/*
 * g3k
 * Copyright 2022 Collabora Ltd.
 * Author: Lubosz Sarnecki <lubosz.sarnecki@collabora.com>
 * SPDX-License-Identifier: MIT
 */

#ifndef G3K_VERSION_H
#define G3K_VERSION_H

#if !defined(G3K_INSIDE) && !defined(G3K_COMPILATION)
# error "Only <g3k.h> can be included directly."
#endif

/**
 * SECTION:xrdversion
 * @short_description: xrdesktop version checking
 *
 * xrdesktop provides macros to check the version of the library
 * at compile-time
 */

/**
 * G3K_MAJOR_VERSION:
 *
 * xrdesktop major version component (e.g. 1 if %G3K_VERSION is 1.2.3)
 */
#define G3K_MAJOR_VERSION (0)

/**
 * G3K_MINOR_VERSION:
 *
 * xrdesktop minor version component (e.g. 2 if %G3K_VERSION is 1.2.3)
 */
#define G3K_MINOR_VERSION (16)

/**
 * G3K_MICRO_VERSION:
 *
 * xrdesktop micro version component (e.g. 3 if %G3K_VERSION is 1.2.3)
 */
#define G3K_MICRO_VERSION (0)

/**
 * G3K_VERSION
 *
 * xrdesktop version.
 */
#define G3K_VERSION (0.16.0)

/**
 * G3K_VERSION_S:
 *
 * xrdesktop version, encoded as a string, useful for printing and
 * concatenation.
 */
#define G3K_VERSION_S "0.16.0"

#define G3K_ENCODE_VERSION(major,minor,micro) \
        ((major) << 24 | (minor) << 16 | (micro) << 8)

/**
 * G3K_VERSION_HEX:
 *
 * xrdesktop version, encoded as an hexadecimal number, useful for
 * integer comparisons.
 */
#define G3K_VERSION_HEX \
        (G3K_ENCODE_VERSION (G3K_MAJOR_VERSION, G3K_MINOR_VERSION, G3K_MICRO_VERSION))

/**
 * G3K_CHECK_VERSION:
 * @major: required major version
 * @minor: required minor version
 * @micro: required micro version
 *
 * Compile-time version checking. Evaluates to %TRUE if the version
 * of xrdesktop is greater than the required one.
 */
#define G3K_CHECK_VERSION(major,minor,micro)   \
        (G3K_MAJOR_VERSION > (major) || \
         (G3K_MAJOR_VERSION == (major) && G3K_MINOR_VERSION > (minor)) || \
         (G3K_MAJOR_VERSION == (major) && G3K_MINOR_VERSION == (minor) && \
          G3K_MICRO_VERSION >= (micro)))

#endif /* G3K_VERSION_H */

